# Niar

A small framework for building projects with [Amaranth]. Provides support for
using [CXXRTL], optionally with [Zig] and [zxxrtl].

See the [template project] for usage, [Sae] for what I'm working on right now,
and [ili9341spi] for a complete example with Zig.

[Amaranth]: https://amaranth-lang.org/
[CXXRTL]: https://yosyshq.readthedocs.io/projects/yosys/en/latest/cmd/write_cxxrtl.html
[Zig]: https://ziglang.org/
[zxxrtl]: https://github.com/kivikakk/zxxrtl
[template project]: https://github.com/kivikakk/niar/tree/main/template
[Sae]: https://github.com/kivikakk/sae
[ili9341spi]: https://github.com/kivikakk/ili9341spi
